@@ -1,6 +1,9 @@
 package X11::GLX::Context;
+$X11::GLX::Context::VERSION = '0.01';
 require X11::GLX; # all comes from XS.  don't need to load this file.
-# ABSTRACT - Opaque wrapper for GLXContext pointer
+
+# ABSTRACT: Opaque wrapper for GLXContext pointer
+
 
 1;
 
@@ -12,11 +15,11 @@ __END__
 
 =head1 NAME
 
-X11::GLX::Context
+X11::GLX::Context - Opaque wrapper for GLXContext pointer
 
 =head1 VERSION
 
-version 0.00_04
+version 0.01
 
 =head1 DESCRIPTION
 
