@@ -1,6 +1,10 @@
 package X11::GLX::Context::Imported;
+$X11::GLX::Context::Imported::VERSION = '0.01';
 require X11::GLX;
-# ABSTRACT - Wrapper for GLXContext which were imported using glXImportContextEXT
+
+# ABSTRACT: Wrapper for GLXContext which were imported using glXImportContextEXT
+
+
 1;
 
 __END__
@@ -11,11 +15,11 @@ __END__
 
 =head1 NAME
 
-X11::GLX::Context::Imported
+X11::GLX::Context::Imported - Wrapper for GLXContext which were imported using glXImportContextEXT
 
 =head1 VERSION
 
-version 0.00_04
+version 0.01
 
 =head1 DESCRIPTION
 
