@@ -1,14 +1,12 @@
 package X11::GLX::DWIM;
-use X11::Xlib;
+$X11::GLX::DWIM::VERSION = '0.01';
 use X11::GLX;
 use OpenGL;
 use Moo;
 use Carp;
 use Log::Any '$log';
 
-our $VERSION= '0.00_04';
-
-# ABSTRACT - Do What I Mean, with OpenGL on X11
+# ABSTRACT: Do What I Mean, with OpenGL on X11
 
 
 has display => ( is => 'lazy' );
@@ -370,11 +368,11 @@ __END__
 
 =head1 NAME
 
-X11::GLX::DWIM
+X11::GLX::DWIM - Do What I Mean, with OpenGL on X11
 
 =head1 VERSION
 
-version 0.00_04
+version 0.01
 
 =head1 SYNOPSIS
 
