@@ -1,8 +1,11 @@
 package X11::GLX::Pixmap;
+$X11::GLX::Pixmap::VERSION = '0.01';
 use strict;
 use warnings;
 use parent 'X11::Xlib::Pixmap';
 
+# ABSTRACT: Object representing a GLX Pixmap
+
 
 sub x_pixmap { my $self= shift; if (@_) { $_->{x_pixmap}= shift; } $_->{x_pixmap} }
 
@@ -24,15 +27,20 @@ __END__
 
 =head1 NAME
 
-X11::GLX::Pixmap
+X11::GLX::Pixmap - Object representing a GLX Pixmap
 
 =head1 VERSION
 
-version 0.00_04
+version 0.01
 
 =head1 DESCRIPTION
 
-Object representing a GLX Pixmap, which is built on top of an X pixmap.
+GLX Pixmaps are built on top of a normal X pixmap by calling
+L<X11::GLX/glXCreateGLXPixmap>, which attaches some buffers needed by OpenGL
+and returns a new X11 resource ID.  The pixmap can then be a rendering target.
+
+The pixmap must also be freed with L<X11::GLX/glXDestroyGLXPixmap>, which this
+module handles.
 
 =head1 ATTRIBUTES
 
@@ -42,8 +50,8 @@ Extends L<X11::Xlib::Pixmap> with:
 
 The X11 pixmap which this GLX pixmap is extending.
 
-The GLX pixmap holds this reference to make sure the X pixmap is not destroyed
-until after the GLX pixmap.
+This GLX pixmap wrapper holds a reference to the X pixmap to make sure it
+isn't destroyed until after the GLX pixmap.
 
 =head1 AUTHOR
 
